Learn R Programming

bayesCureRateModel (version 1.5)

log_lomax: PDF and CDF of the Lomax distribution

Description

The Lomax distribution as evaluated at the VGAM package.

Usage

log_lomax(y, a1, a2, c_under = 1e-09)

Value

A list containing the following entries

log_f

natural logarithm of the pdf, evaluated at each datapoint.

log_F

natural logarithm of the CDF, evaluated at each datapoint.

Arguments

y

observed data

a1

scale parameter

a2

shape parameter

c_under

A small positive value corresponding to the underflow threshold, e.g. c_under = 1e-9.

Author

Panagiotis Papastamoulis

Details

The Lomax distribution is a special case of the 4-parameter generalized beta II distribution.

References

Thomas W. Yee (2015). Vector Generalized Linear and Additive Models: With an Implementation in R. New York, USA: Springer.

See Also

dlomax

Examples

Run this code
log_lomax(y = 1:10, a1 = 1, a2 = 1, c_under = 1e-9)

Run the code above in your browser using DataLab