powered by
The Lomax distribution as evaluated at the VGAM package.
log_lomax(y, a1, a2, c_under = 1e-09)
A list containing the following entries
natural logarithm of the pdf, evaluated at each datapoint.
natural logarithm of the CDF, evaluated at each datapoint.
observed data
scale parameter
shape parameter
A small positive value corresponding to the underflow threshold, e.g. c_under = 1e-9.
Panagiotis Papastamoulis
The Lomax distribution is a special case of the 4-parameter generalized beta II distribution.
Thomas W. Yee (2015). Vector Generalized Linear and Additive Models: With an Implementation in R. New York, USA: Springer.
dlomax
log_lomax(y = 1:10, a1 = 1, a2 = 1, c_under = 1e-9)
Run the code above in your browser using DataLab